
#ifndef _COMLINE_H_
#define _COMLINE_H_

/* Bear Transfer Protocol (BTP), a TCP/IP socket based file 
   transfer utility

  The author of this software is Ian Kaplan
  www.bearcave.com
  iank@bearcave.com

  Copyright (c) Ian Kaplan, 1999

  See "copyright" file for allowed use.

*/


/*
 * command_line
 *

   Base class for processing command line arguments.

   There are two classes derived from this base - one
   for processing the server command line and one to
   process the client command line.

 */
class command_line {
private: // class variables
  const char *prog_name;
  unsigned short port;

private: // class functions
  virtual void usage(void)
  {
    assert( FALSE );
  }

  virtual void parse_comm_line( int argc, char *argv[] )
  {
    assert( FALSE );
  }

protected:
  void init(int argc, char *argv[] )
  {
    prog_name = argv[0];

    // set defaults
    port = DEFAULT_PORT;

    parse_comm_line( argc, argv );

    if (get_port() == 0){ 
      usage(); 
    } 
  }


public:
  command_line()
  {
    prog_name = NULL;
    port = 0;
  }
  
  const unsigned short get_port(void) { return port; }
  void set_port(unsigned int p) { port = p; }
  const char *get_prog_name(void)     { return prog_name; }
}; // command_line



/*
 * command_line_client
 *

   Command line processing for the BTP client.

 */

typedef enum { bad_name_kind, text_name, ip_addr_name } sys_name_kind;

class command_line_client : public command_line {
private: // class variables
  const char *sys_name;
  const char *sys_IP;
  sys_name_kind name_kind;

private: // class functions
  void usage(void);
  void parse_comm_line( int argc, char *argv[] );
  void put_name( const char *name )
  {
    name_kind = text_name;
    sys_name = name;
  }
  void put_ip( const char *ip_addr )
  {
    name_kind = ip_addr_name;
    sys_IP = ip_addr;
  }
  
  Boolean is_ip_addr( const char *ip_addr ); 

public:
  command_line_client (int argc, char *argv[] )
  {
    sys_name = NULL;
    sys_IP = NULL;
    name_kind = bad_name_kind;
    init( argc, argv );
  }
  
  const char *get_sys_name(void)      { return sys_name; }
}; // command_line_client



/*
 * command_line_server
 *

   Command line processing for the BTP server

 */
class command_line_server : public command_line {
private: // class functions
  void usage(void);
  void parse_comm_line( int argc, char *argv[] );

public:
  command_line_server(int argc, char *argv[] )
  {
    init( argc, argv );
  }
}; // command_line_server



#endif
