
#ifndef _COMMANDS_H_
#define _COMMANDS_H_


/* Bear Transfer Protocol (BTP), a TCP/IP socket based file 
   transfer utility

  The author of this software is Ian Kaplan
  www.bearcave.com
  iank@bearcave.com

  Copyright (c) Ian Kaplan, 1999

  See "copyright" file for allowed use.

*/


typedef enum {
  bad_command = 0,
  put_file,            // put file from client to server
  get_file,            // get file from server to client
  acknowledge,         // acknowledge command
  quit,                // terminate the client and server
  send_name,           // file name will be sent
  file_exists,         // file name already exists on remote system
  directory,           // file is a directory
  overwrite_file,      // overwrite file on remote system
  no_such_file,        // file could not be found
  com_error,           // communication error
  could_not_open,      // could not open file
  sending_data,        // data being send to server or client
  send_done,           // send complete
  print_cwd,           // print the current working directory
  change_dir,          // change directory
  local_command,       // local (client side) command
  list_dir,            // list the current directory on the server
  ascii_mode,          // transfer is ascii mode (default - NT translation )
  binary_mode,         // transfer is binary mode (no NT translation)
  help,                // print help display
  about,               // author and use information
  debug_mode,          // debug mode (unknown yet whether on or off)
  debug_mode_on,       // debug mode on
  debug_mode_off,      // debug mode off
  turn_on,             // turn a switch on
  turn_off,            // turn a switch off
  unknown_command,     // the user entered a bad command
  last_command
} COMMANDS;


/*
 * class client_commands
 *

   Get input from stdin and process commands

 */
class client_commands {
private:
  enum { BUFSIZE = 256 } bogus;
  char linebuf[ BUFSIZE ];
  int line_error;
  int buflen;
  char *pChar;

private:
  void skip_leading_white_spaces();
  char get_char(void)
  {
    char ch = '\0';

    if (pChar != NULL) {
      ch = *pChar;
      pChar++;
      buflen--;
    }
    return ch;
  }
  void unget_char(void)
  {
    if (pChar != NULL && pChar > linebuf) {
      pChar--;
      buflen++;
    }
  }
  char *Fgets( char *buf, const int bufsize, FILE *fp );
  int get_buflen(void)     { return buflen; }
  char *get_charptr(void)  { return pChar; }
  void init_buflen()       { buflen = strlen( linebuf); }
  void init_charptr(void)  { pChar = linebuf; }

public:

  void init(void)
  {
    line_error = FALSE;
    linebuf[0] = '\0';
    buflen = 0;
    pChar = NULL;
  }

  client_commands() 
  {
    init();
  }

  void get_line();
  COMMANDS get_command();
  COMMANDS find_command( const char *pWord );
  int get_word( char *pWordBuf, const int buf_size );
  const char *command_name( COMMANDS com );
  Boolean is_yes();
};  // client_commands


#endif
