
#ifndef _FTP_CLIENT_H_
#define _FTP_CLIENT_H_


/* Bear Transfer Protocol (BTP), a TCP/IP socket based file 
   transfer utility

  The author of this software is Ian Kaplan
  www.bearcave.com
  iank@bearcave.com

  Copyright (c) Ian Kaplan, 1999

  See "copyright" file for allowed use.

*/


/*
 * ftp_client
 *
 */
class ftp_client {
private:
  const char *month;
  const size_t day;
  const size_t year;

  // objects
  netfile file_obj;
  netio netio_obj;
  client_commands com;
  iowrap iofunc;

private:
  Boolean ok_to_overwrite( const char *file_name );
  Boolean open_server_dest( int sockfd, const char *destname, 
			    const char *prog_name );
  Boolean open_server_src( int sockfd, const char *srcname, 
			   const char *prog_name);
  void server_cd( int sockfd, const char *prog_name );
  void print_server_cwd( int sockfd, const char *prog_name );
  void put_transfer( int sockfd, const char *srcname, const char *destname,
		     const char *prog_name );
  void get_transfer( int sockfd, const char *srcname, const char *destname,
		     const char *prog_name );
  void get_server_names( int sockfd, 
			 dirnames &dir, 
			 string_heap &strheap,
			 const char *prog_name );
  void server_ls( int sockfd, const char *prog_name );
  void client_ls( const char *progname );
  void local_cd( const char *prog_name );
  void print_local_cwd(const char *prog_name );
  void do_local_commands( const char *prog_name );
  void debug_command( int sockfd, const char *prog_name );
  void title(void);
  void copyright(void);
  void version(void);
  void print_about();
  void help_summary();
  void print_help_display(void);

public:
  void process_commands( int sockfd, const char *prog_name );
  ftp_client( const char *m, const size_t d, const size_t y ) : month( m ), day(d), year( y )
  {
  }
};

#endif
