
/* Bear Transfer Protocol (BTP), a TCP/IP socket based file 
   transfer utility

  The author of this software is Ian Kaplan
  www.bearcave.com
  iank@bearcave.com

  Copyright (c) Ian Kaplan, 1999

  See "copyright" file for allowed use.

*/

#include "netinc.h"
#include "sys/stat.h"
#include "neterr.h"
#include "iowrap.h"
#include "list.h"
#include "strheap.h"
#include "readdir.h"

/*
 * POSIX operating system independent code dor directory read
 *
 */


char *readdir::alloc_name( const char *pFileName )
{
  assert( pFileName != NULL );

  char new_name[ PATH_SIZE ];
  int file_len;

  file_len = strlen( pFileName );
  if (path_len + file_len < PATH_SIZE) {
    iowrap iofunc;

    path[path_len] = '\0';
    strcat( path, pFileName );
    if (iofunc.is_dir( path )) {
      strcpy( new_name, pFileName );
      new_name[ file_len ] = '/';
      file_len++;
      new_name[ file_len ] = '\0';
      pFileName = new_name;
    }
  }

  char *pStr = strheap.alloc_string( pFileName );

  return pStr;
} // alloc_name



char *readdir::get_head( char *dir_path )
{
  int len;
  char *ptr;

  assert( dir_path != NULL );

  len = strlen( dir_path );
  
  for (ptr = &dir_path[ len-1 ]; ptr > dir_path; ptr--)
    if ( is_path_sep( *ptr ) ) {
      ptr++;
      break;
    }

  return ptr;
} // get_head



/*
 * set_path
 *

   Set the root path for the directory being listed

 */
void readdir::set_path( const char *dir_path )
{
  assert( dir_path != NULL );

  path_len = strlen( dir_path );
  if (path_len+1 < PATH_SIZE) {
    strcpy( path, dir_path );

    if (! is_path_sep(path[path_len-1]) ) {
      path[path_len] = path_sep();
      path_len++;
    }
  }
} // set_path




/*
 * operating system dependent code for directory read
 *
 */

#ifdef WIN32

/* 
 * Windows NT 
 */
#include "readdir_nt.C"

#else

/* 
 * UNIX: Solaris/BSD/System V 
 */
#include "readdir_ux.C"

#endif
