
/* Bear Transfer Protocol (BTP), a TCP/IP socket based file 
   transfer utility

  The author of this software is Ian Kaplan
  www.bearcave.com
  iank@bearcave.com

  Copyright (c) Ian Kaplan, 1999

  See "copyright" file for allowed use.

*/

/*
 * readdir_nt.C
 *
 * Windows NT dependent directory read code for the readdir class
 *
 */


Boolean readdir::is_path_sep( char ch )
{
  return (Boolean)(ch == '\\');
} // is_path_sep



char readdir::path_sep(void)
{
  return '\\';
} // path_sep


/*
 * first_file
 *

   Get the first file in the directory list

 */
char *readdir::first_file( const char *dir_path )
{
  char *ret_name = NULL;

  if (dir_path != NULL) {
    struct stat stat_struct;
    int stat_rslt = stat( dir_path, &stat_struct );
    
    if (stat_rslt >= 0) {
      // file exists
      if (stat_struct.st_mode & S_IFDIR) {
	char buf[ 128 ];
	// the file is a directory
	WIN32_FIND_DATA file_ent;
	HANDLE h;
	char *pName;

	set_path( dir_path );

	sprintf(buf, "%s\\*", dir_path );
	h = FindFirstFile( buf, &file_ent );
	cur_state = (void *)h;

	pName = file_ent.cFileName;
	if (pName[0] == '.')
	  while ((pName = next_file()) != NULL && pName[0] =='.')
	    /* nada */;
	if (pName != NULL) {
	  ret_name = alloc_name( pName );
	}
      }
      else {
	// the file exists, but its not a directory, so
	// return the file name at the end of the path
	ret_name = alloc_name( get_head( (char *)dir_path ) );
      }
    }
  }

  return ret_name;
} // get_first_file



/*
 * next_file
 *
  
   Get the next file in the directory list
 */
char *readdir::next_file(void)
{
  char *ret_name = NULL;

  if (cur_state != NULL) {
    WIN32_FIND_DATA file_ent;
    HANDLE h;

    h = (HANDLE)cur_state;
    if (FindNextFile(h, &file_ent)) {
      ret_name = alloc_name( file_ent.cFileName );
    }
    else {
      FindClose( h );
    }
  }

  return ret_name;
} // next_file

