
/* Bear Transfer Protocol (BTP), a TCP/IP socket based file 
   transfer utility

  The author of this software is Ian Kaplan
  www.bearcave.com
  iank@bearcave.com

  Copyright (c) Ian Kaplan, 1999

  See "copyright" file for allowed use.

*/

/*
 * readdir_ux.C
 *
 * UNIX dependent directory read code for the readdir class
 *
 */

#include <dirent.h>


Boolean readdir::is_path_sep( char ch )
{
  return (Boolean)(ch == '/');
} // is_path_sep


char readdir::path_sep(void)
{
  return '/';
} // path_sep


/*
 * first_file
 *

   Get the first file in the directory list

 */
char *readdir::first_file( const char *dir_path )
{
  char *ret_name = NULL;

  if (dir_path != NULL) {
    struct stat stat_struct;
    int stat_rslt = stat( dir_path, &stat_struct );
    
    if (stat_rslt >= 0) {
      // file exists
      if (stat_struct.st_mode & S_IFDIR) {
	// the file is a directory
	set_path( dir_path );
	cur_state = (void *)opendir( dir_path );
	ret_name = next_file();
      }
      else {
	// the file exists, but its not a directory, so
	// return the file name at the end of the path
	ret_name = alloc_name( get_head( (char *)dir_path ) );
      }
    }
  }

  return ret_name;
} // get_first_file



/*
 * next_file
 *
  
   Get the next file in the directory list
 */
char *readdir::next_file(void)
{
  char *ret_name = NULL;

  if (cur_state != NULL) {
    DIR *pDir;
    struct dirent *pDirent;

    pDir = (DIR *)cur_state;

    // Skip the . and .. files
    while ((pDirent = readdir( pDir )) != NULL &&
	   pDirent->d_name[0] == '.')
      /* nada */;
    
    if (pDirent != NULL) {
      char *pFileName;

      pFileName = pDirent->d_name;
      assert( pFileName != NULL );

      ret_name = alloc_name( pFileName );
    }
  }

  return ret_name;
} // next_file
